@@ -4,11 +4,18 @@ package Apache2::ASP::GlobalConfig;
 use strict;
 use warnings 'all';
 use XML::Simple ();
+$XML::Simple::PREFERRED_PARSER = 'XML::Parser';
 use Apache2::ASP::Config;
 use Sys::Hostname ();
 use Cwd 'cwd';
 
 my $CONFIG_FILE = 'apache2-asp-config.xml';
+our $PARSED_XML = {
+  # broken up by config_path:
+};
+our $_CONFIGS = {
+  # broken up by config_path:
+};
 
 
 #==========================================================================
@@ -16,20 +23,30 @@ sub new
 {
 	my ($class, %args) = @_;
 	
+	my $domain = $class->_current_domain;
+	return $_CONFIGS->{$domain} if exists($_CONFIGS->{$domain});
+	
 	my $config_path = $class->find_config_path or die "Cannot find config anywhere!";
 	
 	my $xml = eval {
-		XML::Simple::XMLin( $config_path,
-			ForceArray => [qw/ web_application filter /],
-			SuppressEmpty => '',
-		);
+	  if( exists($PARSED_XML->{$config_path}) && ref($PARSED_XML->{$config_path}) && keys(%{$PARSED_XML->{$config_path}}) )
+	  {
+	    $PARSED_XML->{$config_path};
+	  }
+	  else
+	  {
+		  $PARSED_XML->{$config_path} = XML::Simple::XMLin( $config_path,
+			  ForceArray => [qw/ web_application filter /],
+			  SuppressEmpty => '',
+		  );
+		}# end if()
 	} or die "Cannot load config file '$config_path': $@";
   foreach( @{ $xml->{web_application} } )
   {
 		$_ = Apache2::ASP::Config->new( $_ );
   }# end foreach()
 	
-	return bless $xml, $class;
+	return $_CONFIGS->{$domain} = bless $xml, $class;
 }# end new()
 
 
@@ -43,15 +60,7 @@ sub find_current_config
 {
   my ($s, $r) = @_;
 	
-	my $domain;
-	if( $r )
-	{
-		$domain = $r->hostname || $r->server->server_hostname;
-	}
-	else
-	{
-		$domain = $ENV{HTTP_HOST} || Sys::Hostname::hostname() || 'localhost';
-	}# end if()
+	my $domain = $s->_current_domain( $r );
   
   my $config = $s->domain_config( $domain );
   unless( $config )
@@ -63,6 +72,25 @@ sub find_current_config
 }# end find_current_config()
 
 
+#==============================================================================
+sub _current_domain
+{
+  my ($s, $r) = @_;
+
+	my $domain;
+	if( $r )
+	{
+		$domain = $r->hostname || $r->server->server_hostname;
+	}
+	else
+	{
+		$domain = $ENV{HTTP_HOST} || Sys::Hostname::hostname() || 'localhost';
+	}# end if()
+	
+	return $domain;
+}# end _current_domain()
+
+
 #==========================================================================
 sub domain_config
 {
